<?php
namespace ShopList\Config;
 
/**
* Класс содержит обработчики событий, на которые подписан модуль
*/
class Handlers extends \RS\Event\HandlerAbstract
{
    /**
    * Добавляет подписку на события
    * 
    * @return void
    */
    function init()
    {
        $this
            ->bind('getroute') //getroute - событие сбора маршрутов модулей
            ->bind('getmenus'); //getmenus - событие сбора пунктов меню
    }
     
    /**
    * Возвращает маршруты данного модуля. Откликается на событие getRoute.
    * 
    * @return array of \RS\Router\Route
    */
    public static function getRoute(array $routes) 
    {        
        //Создаем объект маршрута. Здесь:
        // shoplist-front-shops - сокращенное имя контроллера \ShopList\Controller\Front\Shops, оно же ID маршрута
        // array('/shops/{p}/','/shops/') - массив из масок URL, на которые будет откликаться контроллер
        //      {p} - переменная, ожидаемая в данном месте (в нашем случае это номер страницы списка)
        //      Также допустим синтаксис: {p:[\d+]} , где :[\d+]  - регулярное выражение, которому должно соответствовать значение p
        //      Если значение не будет соответствовать, то маршрут не будет откликаться на URI
        // null - не устанавливать значения по-умолчанию переменных в GET
        // Список магазинов сети - название маршрута, будет отображаться в списках админ. панели под этим именем
        $routes[] = new \RS\Router\Route('shoplist-front-shops', 
        array(
            '/shops/{p}/',
            '/shops/'
        ), null, 'Список магазинов сети');
         
        return $routes;
    }
     
    /**
    * Возвращает пункты меню, которые следует добавить в админ. панель
    * 
    * @return array
    */
    public static function getMenus(array $items) 
    {        
        $items[] = array(
            'title' => 'Сеть магазинов',
            'alias' => 'shoplist',
            'link' => '%ADMINPATH%/shoplist-control/', //здесь %ADMINPATH% - URL админ. панели, изменять не нужно, будет автоматически заменено; shoplist - модуль; control - класс фронт контроллера
            'typelink' => 'link', //Тип пункта меню - ссылка
            'parent' => 'modules', //Alias родителя. Пункт будет добавлен в раздел "Разное", у него alias = modules
        );
         
        return $items;
    }    
     
}