<?php
namespace ShopList\Controller\Admin;

use \RS\Html\Table\Type as TableType,
    \RS\Html\Toolbar\Button as ToolbarButton,
    \RS\Html\Filter,
    \RS\Html\Table;
    
/**
* Контроллер Управление списком магазинов сети
*/
class Control extends \RS\Controller\Admin\Crud
{
    function __construct()
    {
        //Устанавливаем, с каким API будет работать CRUD контроллер
        parent::__construct(new \ShopList\Model\Api());
    }
    
    function helperIndex()
    {
        $helper = parent::helperIndex(); //Получим helper по-умолчанию
        $helper->setTopTitle('Магазины сети'); //Установим заголовок раздела
        //Установим, какие кнопки отобразить в нижней панели инструментов
        $helper->setBottomToolbar($this->buttons(array('multiedit', 'delete')));
        //Добавим кнопку импорт/экспорт в CSV, будет использоваться схема экспорта \ShopList\Model\CsvSchema\ShopItem, сокращенно shoplist-shopitem
        $helper->addCsvButton('shoplist-shopitem');
        
        //Опишем колонки табличного представления данных
        $helper->setTable(new Table\Element(array(
            'Columns' => array(
                new TableType\Checkbox('id', array('showSelectAll' => true)), //Отображаем флажок "выделить элементы на всех страницах"
                new TableType\String('address', 'Адрес', array('Sortable' => SORTABLE_BOTH, 'href' => $this->router->getAdminPattern('edit', array(':id' => '@id') ), 'LinkAttr' => array('class' => 'crud-edit') )),
                new TableType\String('city', 'Город', array('Sortable' => SORTABLE_BOTH)),
                new TableType\String('worktime', 'Время работы', array('Sortable' => SORTABLE_BOTH)),
                new TableType\String('phones', 'Телефоны'),
                new TableType\String('id', '№', array('Sortable' => SORTABLE_BOTH, 'CurrentSort' => SORTABLE_ASC, 'TdAttr' => array('class' => 'cell-sgray'))),
                new TableType\Actions('id', array(
                    //Опишем инструменты, которые нужно отобразить в строке таблицы пользователю
                    new TableType\Action\Edit($this->router->getAdminPattern('edit', array(':id' => '~field~')), null, array(
                        'attr' => array(
                            '@data-id' => '@id'
                        ))),
                    ),
                    //Включим отображение кнопки настройки колонок в таблице
                    array('SettingsUrl' => $this->router->getAdminUrl('tableOptions'))
                ),
            )
        )));
        
        //Опишем фильтр, который следует добавить
        $helper->setFilter(new Filter\Control(array(
            'Container' => new Filter\Container( array( //Контейнер визуального фильтра
                'Lines' =>  array(
                    new Filter\Line( array('Items' => array( //Одна линия фильтров
                            new Filter\Type\String('id','№', array('attr' => array('class' => 'w50'))), //Фильтр по ID
                            new Filter\Type\String('city','Город', array('searchType' => '%like%')), //Фильтр по городу
                        )
                    )),
                )
            )),
            'Caption' => 'Поиск по магазинам'
        )));
        
        return $helper;
    }
}
